@@ -302,7 +302,7 @@ class LifReader(Reader):
         blocked_shape = tuple(non_chunk_shape) + ((1,) * len(chunk_shape))
 
         # Make ndarray for lazy arrays to fill
-        lazy_arrays = np.ndarray(blocked_shape, dtype=object)
+        lazy_arrays: np.ndarray = np.ndarray(blocked_shape, dtype=object)
         for np_index, _ in np.ndenumerate(lazy_arrays):
             # All dimensions get their normal index except for chunk dims
             # which get None, which tell the get data func to pull the whole dim
